@@ -42,7 +42,9 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 /* Main control */
 
@@ -216,7 +218,9 @@ axel_new(conf_t *conf, int count, const search_t *res)
 		 * depends on the protocol used. */
 		status = conn_info(&axel->conn[0]);
 		if (!status) {
-			axel_message(axel, "%s", axel->conn[0].message);
+			char msg[80];
+			int code = conn_info_status_get(msg, sizeof(msg), axel->conn);
+			fprintf(stderr, _("ERROR %d: %s.\n"), code, msg);
 			axel->ready = -1;
 			return axel;
 		}
@@ -913,7 +917,7 @@ axel_divide(axel_t *axel)
 	axel->conn[axel->conf->num_connections - 1].lastbyte += tail;
 #ifndef NDEBUG
 	for (int i = 0; i < axel->conf->num_connections; i++) {
-		printf(_("Downloading %lld-%lld using conn. %i\n"),
+		printf(_("Downloading %jd-%jd using conn. %i\n"),
 		       axel->conn[i].currentbyte,
 		       axel->conn[i].lastbyte, i);
 	}
