@@ -4,7 +4,7 @@
   Copyright 2001-2007 Wilmer van der Gaast
   Copyright 2007-2008 Y Giridhar Appaji Nag
   Copyright 2016      Stephen Thirlwall
-  Copyrigth 2017      Antonio Quartulli
+  Copyright 2017      Antonio Quartulli
   Copyright 2017-2019 Ismael Luceno
 
   This program is free software; you can redistribute it and/or
@@ -34,7 +34,9 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 /* FTP control file */
 
@@ -306,7 +308,6 @@ int
 ftp_wait(ftp_t *conn)
 {
 	int size = MAX_STRING, r = 0, complete, i, j;
-	char *s;
 
 	{
 		void *new_msg = realloc(conn->message, size);
@@ -358,12 +359,8 @@ ftp_wait(ftp_t *conn)
 	fprintf(stderr, "fd(%i)-->%s", conn->tcp.fd, conn->message);
 #endif
 
-	if ((s = strchr(conn->message, '\n')) != NULL)
-		*s = 0;
-	if ((s = strchr(conn->message, '\r')) != NULL)
-		*s = 0;
-	conn->message =
-	    realloc(conn->message, max(strlen(conn->message) + 1, MAX_STRING));
-
+	int k = strcspn(conn->message, "\r\n");
+	conn->message[k] = 0;
+	conn->message = realloc(conn->message, k + 1);
 	return conn->status;
 }
