@@ -41,7 +41,9 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 /* Text interface */
 
@@ -82,6 +84,7 @@ static struct option axel_options[] = {
 	{"help",            0,      NULL, 'h'},
 	{"version",         0,      NULL, 'V'},
 	{"alternate",       0,      NULL, 'a'},
+	{"percentage",      0,      NULL, 'p'},
 	{"insecure",        0,      NULL, 'k'},
 	{"no-clobber",      0,      NULL, 'c'},
 	{"header",          1,      NULL, 'H'},
@@ -91,6 +94,16 @@ static struct option axel_options[] = {
 };
 #endif
 
+/**
+ * Unified percentage calculation for all progress indicators.
+ */
+static
+unsigned
+calc_percentage(off_t cur, off_t total)
+{
+	return min(100, (100 * cur + total / 2) / total);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -120,7 +133,7 @@ main(int argc, char *argv[])
 	j = -1;
 	while (1) {
 		int option = getopt_long(argc, argv,
-					 "s:n:o:S::46NqvhVakcH:U:T:",
+					 "s:n:o:S::46NqvhVapkcH:U:T:",
 					 axel_options, NULL);
 		if (option == -1)
 			break;
@@ -178,6 +191,9 @@ main(int argc, char *argv[])
 		case 'a':
 			conf->alternate_output = 1;
 			break;
+		case 'p':
+			conf->percentage = 1;
+			break;
 		case 'k':
 			conf->insecure = 1;
 			break;
@@ -219,10 +235,11 @@ main(int argc, char *argv[])
 		}
 	}
 
-	/* disable alternate output and verbosity when quiet is specified */
-	if (conf->verbose < 0)
+	/* disable alternate outputs and verbosity when quiet is specified */
+	if (conf->verbose < 0) {
 		conf->alternate_output = 0;
-	else if (j > -1)
+		conf->percentage = 0;
+	} else if (j > -1)
 		conf->verbose = j;
 
 	if (conf->num_connections < 1) {
@@ -262,7 +279,9 @@ main(int argc, char *argv[])
 		}
 	}
 
-	printf(_("Initializing download: %s\n"), s);
+	if (!conf->percentage)
+		printf(_("Initializing download: %s\n"), s);
+
 	if (do_search) {
 		search = calloc(conf->search_amount + 1, sizeof(search_t));
 		if (!search)
@@ -380,7 +399,7 @@ main(int argc, char *argv[])
 	axel_start(axel);
 	print_messages(axel);
 
-	if (conf->alternate_output) {
+	if (conf->alternate_output || conf->percentage) {
 		putchar('\n');
 	} else {
 		if (axel->bytes_done > 0) {	/* Print first dots if resuming */
@@ -401,7 +420,10 @@ main(int argc, char *argv[])
 		prev = axel->bytes_done;
 		axel_do(axel);
 
-		if (conf->alternate_output) {
+		if (conf->percentage) {
+			if (!axel->message && prev != axel->bytes_done)
+				printf("%u\n", calc_percentage(axel->bytes_done, axel->size));
+		} else 	if (conf->alternate_output) {
 			if (!axel->message && prev != axel->bytes_done)
 				print_alternate_output(axel);
 		} else if (conf->verbose > -1) {
@@ -539,8 +561,8 @@ print_progress(off_t cur, off_t prev, off_t total, double kbps)
 			if (total == LLONG_MAX)
 				printf("\n[ N/A]  ");
 			else
-				printf("\n[%3jd%%]  ",
-				       min(100U, 102400 * i / total));
+				printf("\n[%3u%%]  ",
+				       calc_percentage(1024 * i, total));
 		} else if (i % 10 == 0) {
 			putchar(' ');
 		}
@@ -584,8 +606,7 @@ print_alternate_output_progress(axel_t *axel, char *progress, int width,
 	}
 
 	progress[width] = '\0';
-	printf("\r[%3ld%%] [%s", min(100, (long)(done * 100. / total + .5)),
-	       progress);
+	printf("\r[%3u%%] [%s", calc_percentage(done, total), progress);
 }
 
 static void
@@ -678,6 +699,7 @@ print_help(void)
 		 "-q\tLeave stdout alone\n"
 		 "-v\tMore status information\n"
 		 "-a\tAlternate progress indicator\n"
+		 "-p\tPrint simple percentages instead of progress bar (0-100)\n"
 		 "-h\tThis information\n"
 		 "-T x\tSet I/O and connection timeout\n"
 		 "-V\tVersion information\n"
@@ -701,6 +723,7 @@ print_help(void)
 		 "--quiet\t\t\t-q\tLeave stdout alone\n"
 		 "--verbose\t\t-v\tMore status information\n"
 		 "--alternate\t\t-a\tAlternate progress indicator\n"
+		 "--percentage\t\t-p\tPrint simple percentages instead of progress bar (0-100)\n"
 		 "--help\t\t\t-h\tThis information\n"
 		 "--timeout=x\t\t-T x\tSet I/O and connection timeout\n"
 		 "--version\t\t-V\tVersion information\n"
